@@ -5,15 +5,17 @@
 
 #include "ape_reorder.h"
 
-extern SEXP _TreeTools_phangorn_bipCPP(SEXP, SEXP);
 extern SEXP _TreeTools_cpp_edge_to_splits(SEXP, SEXP);
 extern SEXP _TreeTools_preorder_edges_and_nodes(SEXP, SEXP);
 extern SEXP _TreeTools_postorder_edges(SEXP);
+extern SEXP _TreeTools_root_on_node(SEXP, SEXP);
+extern SEXP _TreeTools_root_binary(SEXP, SEXP);
 extern SEXP _TreeTools_num_to_parent(SEXP, SEXP);
 extern SEXP _TreeTools_edge_to_num(SEXP, SEXP, SEXP);
 extern SEXP _TreeTools_edge_to_rooted_shape(SEXP, SEXP, SEXP);
 extern SEXP _TreeTools_random_parent(SEXP, SEXP);
 extern SEXP _TreeTools_rooted_shape_to_edge(SEXP, SEXP);
+extern SEXP _TreeTools_tips_in_splits(SEXP, SEXP);
 extern SEXP _TreeTools_as_newick(SEXP);
 
 static const R_CMethodDef cMethods[] = {
@@ -30,9 +32,11 @@ static const R_CallMethodDef callMethods[] = {
   {"_TreeTools_random_parent", (DL_FUNC) &_TreeTools_random_parent, 2},
   {"_TreeTools_rooted_shape_to_edge", (DL_FUNC) &_TreeTools_rooted_shape_to_edge, 2},
   {"_TreeTools_cpp_edge_to_splits", (DL_FUNC) &_TreeTools_cpp_edge_to_splits, 2},
-  {"_TreeTools_phangorn_bipCPP", (DL_FUNC) &_TreeTools_phangorn_bipCPP, 2},
   {"_TreeTools_preorder_edges_and_nodes", (DL_FUNC) &_TreeTools_preorder_edges_and_nodes, 2},
   {"_TreeTools_postorder_edges", (DL_FUNC) &_TreeTools_postorder_edges, 1},
+  {"_TreeTools_root_on_node", (DL_FUNC) &_TreeTools_root_on_node, 2},
+  {"_TreeTools_root_binary", (DL_FUNC) &_TreeTools_root_binary, 2},
+  {"_TreeTools_tips_in_splits", (DL_FUNC) &_TreeTools_tips_in_splits, 1},
   {"_TreeTools_as_newick", (DL_FUNC) &_TreeTools_as_newick, 1},
   {NULL, NULL, 0}
 };
